@@ -1,4 +1,4 @@
-# $Id: install.py 1467 2016-03-14 15:36:18Z mwall $
+# $Id: install.py 1600 2016-12-09 04:53:21Z mwall $
 # installer for the forecast extension
 # Copyright 2014-2016 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.1.3",
+            version="3.2.0",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
@@ -63,8 +63,22 @@ class ForecastInstaller(ExtensionInstaller):
                      'skins/compare/index.html.tmpl']),
                    ('skins/forecast',
                     ['skins/forecast/skin.conf',
+                     'skins/forecast/forecast.css',
+                     'skins/forecast/forecast-periods.html.tmpl',
+                     'skins/forecast/forecast_iconic.css',
+                     'skins/forecast/forecast_iconic.inc',
+                     'skins/forecast/forecast_strip.css',
+                     'skins/forecast/forecast_strip.inc',
+                     'skins/forecast/forecast_table.css',
                      'skins/forecast/forecast_table.inc',
-                     'skins/forecast/index.html.tmpl']),
+                     'skins/forecast/iconic.html.tmpl',
+                     'skins/forecast/index.html.tmpl',
+                     'skins/forecast/multiple-strips.html.tmpl',
+                     'skins/forecast/multiple-tables.html.tmpl',
+                     'skins/forecast/single-strip.html.tmpl',
+                     'skins/forecast/single-table.html.tmpl',
+                     'skins/forecast/tides.html.tmpl',
+                     'skins/forecast/zambretti.html.tmpl']),
                    ('skins/forecast/icons',
                     ['skins/forecast/icons/AF.png',
                      'skins/forecast/icons/B1.png',
